@@ -7,7 +7,7 @@ import pandas as pd
 from pprint import pprint
 import sys
 
-from .utils import myopen
+from augur.io import open_file
 
 TITER_ROUND=4
 
@@ -35,6 +35,7 @@ class TiterCollection(object):
         tuple (dict, list, list)
             tuple of a dict of titer measurements, list of strains, list of sources
 
+
         >>> measurements, strains, sources = TiterCollection.load_from_file("tests/data/titer_model/h3n2_titers_subset.tsv")
         >>> type(measurements)
         <class 'dict'>
@@ -66,7 +67,7 @@ class TiterCollection(object):
         titer_files = [filenames] if type(filenames)==str else filenames
 
         for fname in titer_files:
-            with myopen(fname, 'r') as infile:
+            with open_file(fname, 'r') as infile:
                 for line in infile:
                     entries = line.strip().split('\t')
                     try:
@@ -107,6 +108,7 @@ class TiterCollection(object):
         dict
             number of measurements per strain
 
+
         >>> measurements, strains, sources = TiterCollection.load_from_file("tests/data/titer_model/h3n2_titers_subset.tsv")
         >>> titer_counts = TiterCollection.count_strains(measurements)
         >>> titer_counts["A/Acores/11/2013"]
@@ -142,6 +144,7 @@ class TiterCollection(object):
             reduced dictionary of titer measurements containing only those were
             test and reference virus are part of the strain list
 
+
         >>> measurements, strains, sources = TiterCollection.load_from_file("tests/data/titer_model/h3n2_titers_subset.tsv")
         >>> len(measurements)
         11
